# Image Hashing powered by Rust

`imghash-py` is a package that contains Python bindings for the Rust crate `imghash-rs` that allows you to generate various image hashes. the following hashes are supported:

* Average Hash
* Difference Hash
* Perceptual Hash

If you want to know more about the different hashes or how they get encoded / decoded, check the documentation of [`imghash-rs`](https://github.com/YannickAlex07/imghash-rs).

## Getting Started

To get started add the package to your project:

```shell
pip install imghash
```

...